import os

from fabric.context_managers import settings
from fabric.decorators import task
from fabric.operations import local
from fabric.state import env

__author__ = 'deanmercado'


@task
def deploy():
    """
    Starts deploy process
    :return:
    """
    ENVIRONMENT_OPTIONS = {}
    if not os.path.exists("orchestration"):
        print("You aren't in a Yurt project. Use `cd` to get in the right directory.")
        return
    if env.get("env", None) is None:
        print("Option\tInventory")
        for index, filename in enumerate(os.listdir("./orchestration/inventory")):
            if not(filename == "vagrant"):
                try:
                    ENVIRONMENT_OPTIONS[str(index)] = filename
                    print("{0}:\t{1}".format(index, filename))
                except KeyError:
                    print("Bad input! Try again")
                    return

        with settings(warn_only=True):
            num_selection = raw_input("Which environment do you want to deploy (use Option number)?:\t")
            selection = ENVIRONMENT_OPTIONS[num_selection]
    else:
        selection = env.env
    local('ansible-playbook -i orchestration/inventory/{0} orchestration/site.yml'.format(selection))



import string
from Crypto.PublicKey import RSA
from fabric.context_managers import prefix, settings
from fabric.operations import local, os
import re
from random import choice
from fabric.state import env
import sys

__author__ = 'deanmercado'

###
# helper functions
###


def get_fab_settings():
    try:
        return __import__("fabric_settings", globals(), locals(), [], 0).FABRIC
    except ImportError:
        try:
            sys.path.append(".")
            return __import__("fabric_settings", globals(), locals(), [], 0).FABRIC
        except ImportError:
            raise ImportError('Create `fabric_settings.py` file in this directory')


def get_file_text(path):
    """
    Gets the text from a file
    :param path:
    :return: String
    """
    with open(path, 'r') as file_item:
        result = file_item.read()
    return result


def _perform_substitution(filepath, dictionary, pattern, all_vars_pattern):
    """
    Get text, find all the variables, and then for each variable found,
    create a new pattern and run re.sub to substitute all instances with
    the dictionary
    :param filepath: str
    :param dictionary: dict
    :param pattern: raw str
    :param all_vars_pattern: raw str
    :return: Void
    """

    file_text = get_file_text(filepath)
    change_vars = re.findall(all_vars_pattern, file_text)
    for variable in change_vars:
        var_pattern = pattern.format(variable)
        if "." in variable:
            env_key, variable = variable.split('.')
            target_dictionary = dictionary.get(env_key).copy()
        else:
            target_dictionary = dictionary.copy()
        file_text = re.sub(var_pattern, target_dictionary.get(variable), file_text)
    with open(filepath, 'w') as change_file:
        change_file.write(file_text)


def recursive_file_modify(path, dictionary, pattern=r"%\(({0})\)s", is_dir=True):
    """
    Recursively modifies all files in a given directory with a replacement dictionary
    :param path: a given path
    :param dictionary: a dictionary of key-value pairs that must be replaced in files
    :param pattern: a regex-pattern that is searched for in each file (the default searches for "%()s")
    :return: Void
    """
    # Pattern for finding all the variables invoked in a file
    all_vars_pattern = pattern.format(r"[^\)]*")

    # Iterates through every item in the given path
    if is_dir:
        for item in os.listdir(path):
            itempath = os.path.join(path, item)
            # If directory, call this function again
            if os.path.isdir(itempath) and not(itempath in [".", ".."]):
                recursive_file_modify(itempath, dictionary, pattern)
            else:
                _perform_substitution(itempath, dictionary, pattern, all_vars_pattern)
    else:
        _perform_substitution(path, dictionary, pattern, all_vars_pattern)


def _get_bashrc():
    """
    Gets the text in ~/.bashrc
    :return: String, the bashrc text
    """
    bash_path = '~/.bashrc'
    try:
        with open(os.path.expanduser(bash_path), 'r') as bashrc:
            bash_text = bashrc.read()
    except Exception:
        bash_path = '~/.bash_profile'
        with open(os.path.expanduser(bash_path), 'r') as bash_profile:
            bash_text = bash_profile.read()
    return bash_text, bash_path


def add_fab_path_to_bashrc():
    """
    Adds FAB_PATH variable to .bashrc
    :return: Void
    """
    with prefix('cd fabfile'):
        bashrc_text, bash_path = _get_bashrc()
        with open(os.path.expanduser(bash_path), 'w') as bashrc:
            if "export FAB_PATH" in bashrc_text:
                bashrc_text = re.sub(r'export FAB_PATH=[^\n]*\n', '', bashrc_text)
            bashrc.write(bashrc_text)
        local('echo "export FAB_PATH=$(pwd -P)" >> {0}'.format(bash_path))


def generate_printable_string(num_chars, special_chars=True):
    """
    Generates a random string of printable characters
    :param num_chars: number (int) of characters for the string to be
    :return: String
    """
    result = ""
    all_chars = string.printable.strip(string.whitespace)
    if not special_chars:
        all_chars = all_chars.strip(string.punctuation)
    while num_chars > 0:
        insert_char = choice(all_chars)
        if insert_char not in "\"'`\\{}$()":
            result = "".join((result, insert_char))
            num_chars -= 1
    return result


def generate_ssh_keypair(in_template=True):
    """
    Generates a 4096 bit ssh-keypair
    :param: bool
    :return: tuple (str, str)
    """
    key = RSA.generate(4096)
    public = key.publickey().exportKey('OpenSSH')
    if type(public) == ValueError:
        public = """
            This version of PyCrypto doesn't fully support key exporting to
            `OpenSSH` format. You can create a public key manually using `ssh-keygen`
            and the private key below. Replace this message with the public key
            (on one line).
        """
    private = key.exportKey('PEM')
    if in_template:
        private = re.sub(r"\n", "\n  ", private)
    return public, private


def get_environment_pem(message='', name_only=False):
    env.settings = get_fab_settings()
    if name_only:
        environments = {
            '1': 'development',
            '2': 'staging',
            '3': 'production'
        }
    else:
        environments = {
            '1': env.settings.get('development'),
            '2': env.settings.get('staging'),
            '3': env.settings.get('production')
        }
    try:
        environment = environments[raw_input("""
        Choose which environment (1-3) <{0}>:
        (1) Development
        (2) Staging
        (3) Production
         Choice:\t""").format(message)]
    except KeyError:
        environment = None
    return environment


def get_project_name_from_repo(repo_link, drop_hyphens=True):
    result = re.search(r"\.com[/:][^/]+/(.*)(\.git)?$", repo_link).group(1)
    result = re.sub(r"\.git$", "", result)
    if drop_hyphens:
        result = re.sub(r"\-", "", result)
    return result


def raw_input_wrapper(query, lower=False):
    usr_input = raw_input(query)
    if lower:
        usr_input = usr_input.lower()
    return usr_input



import os
import sys
from django.core.wsgi import get_wsgi_application

PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "config.settings.local")

sys.path.append(os.path.abspath(os.path.join(PROJECT_ROOT, "../../")))

application = get_wsgi_application()



import os
from os.path import dirname, abspath

CONFIG_ROOT = dirname(dirname(abspath(__file__)))

# Absolute filesystem path to the project directory:
PROJECT_ROOT = dirname(CONFIG_ROOT)

# Name of the directory for the project.
PROJECT_DIRNAME = PROJECT_ROOT.split(os.sep)[-1]

# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'compressor',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
)

STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'compressor.finders.CompressorFinder',
)

ROOT_URLCONF = 'config.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': '%(project_name)s',
        'USER': '%(project_name)s',
        'PASSWORD': os.getenv('DATABASE_PASSWORD', '%(vagrant.db_password)s'),
        'HOST': os.getenv('DATABASE_HOST', '%(vagrant.db_host_ip)s'),
        'PORT': "5432",
    }
}

WSGI_APPLICATION = 'config.wsgi.application'


LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(PROJECT_ROOT, STATIC_URL.strip("/"))

MEDIA_URL = STATIC_URL + "media/"
MEDIA_ROOT = os.path.join(PROJECT_ROOT, *MEDIA_URL.strip("/").split("/"))



import os
from collections import OrderedDict

from fabric.context_managers import lcd
from fabric.operations import local

from utils import get_project_name_from_repo, generate_printable_string, recursive_file_modify, raw_input_wrapper
from cli import main
from setup import YURT_PATH

TEMPLATES_PATH = os.path.join(YURT_PATH, "templates")

ATTRIBUTE_TO_QUESTION_MAPPING = OrderedDict([
    ("git_repo", "Enter the git repository link\n(i.e. git@github.com:mr_programmer/robot_repository.git):\t"),
    ("env", "What name is this environment (i.e. development, staging, production)?: "),
    ("abbrev_env", "How do you want this environment abbreviated (i.e. dev, stage, prod)?: "),
    ("app_host_ip", "What is the public DNS of this project's host (i.e. example.com)?: "),
    ("db_host_ip", "What is this project's DB host (Hint: public IP of project if hosted locally)?: "),
    ("debug", "This Django server will use Debug mode (True/False): "),
    ("num_gunicorn_workers", "".join(("How many gunicorn workers do you want ",
                                      "(Hint: For the number of workers, a go",
                                      "od rule to follow is 2 x number of CPUs + 1)?: "))),
    ("gunicorn_max_requests", "".join(("What do you want to set `gunicorn_max_requests` to ? ",
                                       "Setting this to 1 will restart the Gunicorn process each time ",
                                       "you make a request, basically reloading the code. Very han",
                                       "dy when developing. Set to 0 for unlimited requests.: "))),
    ("ssl_enabled", "Is SSL enabled on this server (yes/no)?: "),
    ("git_branch", "From which git branch will the server pull the project?: ")
])

TEMPLATE_TO_PROJECT_MAPPING = {
    "./env_settings.py.template.py": "../{0}/config/settings/{1}.py",
    "./env_vars.yml.template": "../{0}/orchestration/env_vars/{2}.yml",
    "./inventory.template": "../{0}/orchestration/inventory/{2}"
}


# @task
@main.command()
def remote_server():
    """
    Adds remote server files for deploying to new remote servers
    :return:
    """
    if os.path.exists("./templates.tmp"):
        print "A `templates.tmp` directory is in the current working directory. Delete this before trying again."
        return None
    lowercase_attrs = ["env", "abbrev_env"]
    settings = {
        "secret_key": generate_printable_string(40),
        "db_password": generate_printable_string(20, False),
    }
    raw_input("You will be asked a bunch of questions for setting up the server.\nMake sure your "
              "input is as accurate as possible.\nIf given a choice in parentheses, make sure\n"
              "the input you enter matches one of those choices.\n"
              "Press Enter to Continue.")

    for attribute, prompt in ATTRIBUTE_TO_QUESTION_MAPPING.iteritems():
        settings[attribute] = raw_input_wrapper(prompt, attribute in lowercase_attrs)
    settings["repo_name"] = get_project_name_from_repo(settings.get("git_repo"), False)
    settings["project_name"] = get_project_name_from_repo(settings.get("git_repo"))
    settings_path = "".join(("./{0}/config/settings/{1}".format(settings.get("project_name"),
                                                                settings.get("abbrev_env")),
                             ".py"))
    settings["settings_path"] = ".".join(settings_path.split("/")[2:])
    settings["settings_path"] = ".".join(settings["settings_path"].split(".")[:-1])

    print "Current Settings: \n{"
    for attr, value in settings.iteritems():
        print "{0} : {1}, ".format(attr, value)
    print "}\n"
    raw_input("Press Enter to Continue or Ctrl+C to Cancel")
    local("cp -rf {0} ./templates.tmp".format(TEMPLATES_PATH))
    recursive_file_modify("./templates.tmp", settings)
    with lcd("./templates.tmp"):
        for filepath, dest_template in TEMPLATE_TO_PROJECT_MAPPING.iteritems():
            destination = dest_template.format(settings.get("project_name"),
                                               settings.get("abbrev_env"),
                                               settings.get("env"))
            local("mv {0} {1}".format(filepath, destination))
    local("rm -rf ./templates.tmp")



from contextlib import contextmanager
from fabric.context_managers import prefix, cd, lcd
import os

###
# Context Managers
###


@contextmanager
def bash():
    if os.path.exists(os.path.expanduser("~/.bashrc")):
        with prefix('source ~/.bashrc'):
            yield
    else:
        with prefix('source ~/.bash_profile'):
            yield


@contextmanager
def venv(project_name):
    with bash():
        with prefix('workon {}'.format(project_name)):
            yield


@contextmanager
def in_project(project_name):
    with lcd(project_name):
        yield



"""
Welcome to the `fabric_settings.py` file!

Below is a field that will fill in the Ansible configurations with your desired
values. Once you're finished, save and then do a fab command. To see the list of
fab commands, enter in `fab -l`.

"""

FABRIC = {
    'git_repo': '',  # Git repo url (either git@github.com:<user>/<repo>.git or https://github.com/<user>/<repo>
    'git_pub_key': """%(git_public_key)s""",  # Key to submit to github.com in settings (for deployment)
    'git_priv_key': """%(git_private_key)s""", # Key to add to keychain of any deploying client computer
    'vagrant': {
        'db_password': '%(vagrant.db_pw)s',
        'db_host_ip': '127.0.0.1',  # IP Address or Host DNS of Database
        'secret_key': '%(vagrant.secret_key)s',
        'settings_path': 'config.settings.local',
    }
}



import os
import click

from fabric.context_managers import settings, lcd
from fabric.contrib.files import append
from fabric.operations import local, run
from fabric.state import env

from utils import recursive_file_modify, get_fab_settings, \
    generate_printable_string, generate_ssh_keypair, get_environment_pem, get_project_name_from_repo
from cli import main

__author__ = 'deanmercado'

###
# fab setup commands: these commands setup a new django project
###

YURT_PATH = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
FABFILE_PATH = os.path.join(YURT_PATH, 'fabfile')
DJANGO_PROJECT_PATH = os.path.join(YURT_PATH, 'django_project')
ORCHESTRATION_PROJECT_PATH = os.path.join(YURT_PATH, 'orchestration')


def create_project():
    """
    Creates Django project by copying over
    :return: Void
    """
    env.settings = get_fab_settings()
    env.proj_name = get_project_name_from_repo(env.settings.get('git_repo'))
    env.settings['project_name'] = env.proj_name
    local("cp -rf {0} ./{1}".format(DJANGO_PROJECT_PATH, env.proj_name))
    recursive_file_modify(os.path.abspath("./{0}".format(env.proj_name)), env.settings)


@main.command()
def load_orchestration_and_requirements():
    """
    Copies over the orchestration directory and requirements.txt file to current directory
    :return: Void
    """
    env.settings = get_fab_settings()
    env.proj_name = get_project_name_from_repo(env.settings.get('git_repo'))
    env.repo_name = get_project_name_from_repo(env.settings.get('git_repo'), False)
    env.settings['project_name'] = env.proj_name
    env.settings['repo_name'] = env.proj_name

    local('cp -rf {0} ./{1}'.format(ORCHESTRATION_PROJECT_PATH, env.proj_name))
    local('cp -f {0} ./{1}'.format(os.path.join(FABFILE_PATH, 'requirements.txt'),
                                                          env.proj_name))
    recursive_file_modify('./{0}/orchestration'.format(env.proj_name), env.settings)


def enable_git_repo():
    """
    Sets up git repository in project direcory
    :return: Void
    """
    env.settings = get_fab_settings()
    env.proj_name = get_project_name_from_repo(env.settings.get('git_repo'))

    if env.proj_name not in os.listdir('.'):
        local('mkdir {0}'.format(env.proj_name))

    with lcd(env.proj_name):
        with settings(warn_only=True):
            local('git init')
            local('git remote add origin {0}'.format(env.git_repo_url))
            local('git checkout -b develop')


def move_vagrantfile_to_project_dir():
    """
    Moves Vagrantfile from `orchestration` directory to project directory
    :return:
    """
    env.settings = get_fab_settings()
    env.proj_name = get_project_name_from_repo(env.settings.get('git_repo'))
    local('mv ./{0}/orchestration/Vagrantfile .'.format(env.proj_name))


@main.command()
def create_pem_file():
    """
    Generates an SSH Key Pair (that is added to your keychain and `~/.ssh` directory)
    :return:
    """
    pub, pem = generate_ssh_keypair(in_template=False)

    project_name = raw_input("What will you name this ssh_key?\
    (Hint: just an alphanumeric name that describes what the key is for):\t")

    with open("./{0}.pem".format(project_name), 'w') as key:
        key.write(pem)
        os.chmod("./{0}.pem".format(project_name), 0400)
        local("mv ./{0}.pem ~/.ssh".format(project_name))
    with open("./{0}.pub".format(project_name), 'w') as key:
        key.write(pub)
        local("mv ./{0}.pub ~/.ssh".format(project_name))
        local("ssh-add ~/.ssh/{0}.pem".format(project_name))
    print("PEM-file `~/.ssh/{0}.pem` added!".format(project_name))


@main.command()
def copy_pem_file(user=None, host=None, key_name=None):
    """
    Appends public SSH Key (named after `project_name` in `fabric_settings.py`) to remote host
    :param user: str, Remote user
    :param host: str, Remote ip address
    :param key_name: str, Name of Key_pair in ~/.ssh
    :return:
    """
    project_name = key_name
    env.user = user
    env.host_string = host

    if user is None:
        user = raw_input("SSH User? (default: 'root'):\t")
        if user.strip(" ") == "":
            env.user = "root"
        else:
            env.user = user
    if host is None:
        env.host_string = raw_input("Public IP/DNS of Remote Server?:\t")
    if key_name is None:
        KEYNAME_ENUM = {}
        key_names = set([filename.split('.')[0]
                         if "." in filename
                         else filename
                         for filename in os.listdir(os.path.expanduser("~/.ssh"))])
        key_names.remove("config")
        print("Option\tKeyname")
        print("______\t_______")
        for index, keyname in enumerate(key_names):
            KEYNAME_ENUM[str(index)] = keyname
            print("{0}:\t{1}".format(index, keyname))
        print("")
        try:
            project_name = KEYNAME_ENUM[raw_input("".join(("Which key in ~/.ssh are you ",
                                                           "copying to the remote server (Input the option)?:\t")))]
        except KeyError:
            raise KeyError("Not a good input!")
            return
    print("If prompted for 'Passphrase for private key:', input the password credentials for this server.")
    run('mkdir -p ~/.ssh')
    with open(os.path.expanduser('~/.ssh/{0}.pub'.format(project_name)), 'r') as key:
        append("~/.ssh/authorized_keys", key.readline().rstrip("\n"))
    if env.user == "root":
        print("Pub key added to `/{0}/.ssh/authorized_keys` in server".format(env.user))
    else:
        print("Pub key added to `/home/{0}/.ssh/authorized_keys` in server".format(env.user))


def delete_fabric_settings():
    """
    Deletes `fabric_settings.py`
    :return: None
    """
    backup_fab_settings = raw_input("Backup `fabric_settings.py` before it's deleted (Y/N)?")
    if backup_fab_settings.lower() == 'y':
        print('Backing up `fabric_settings.py` => `fabric_settings.py.bak`')
        local('cp fabric_settings.py fabric_settings.py.bak')
    elif backup_fab_settings.lower() == 'n':
        print('No backup made!')
    else:
        print('Bad input. Re-run by calling `fab setup.delete_fabric_settings`')
        return None
    print('Deleting `fabric_settings`')
    local('rm fabric_settings.py')
    local('rm *.pyc')


@main.command()
@click.pass_context
def new_project():
    """
    Create new project
    :return: None
    """
    env.settings = get_fab_settings()
    env.proj_name = get_project_name_from_repo(env.settings.get('git_repo'))
    env.settings['project_name'] = env.proj_name
    env.git_repo_url = env.settings.get('git_repo')
    enable_git_repo()
    create_project()
    load_orchestration_and_requirements()
    move_vagrantfile_to_project_dir()
    delete_choice = {
        'y': True,
        'n': False
    }
    local('vagrant up')
    try:
        delete_setting = delete_choice[raw_input('''Delete `fabric_settings.py` file (Y/N)?
Hint: If you plan on running more fab calls after this, enter `N`.\nChoice:\t''').lower()]
    except KeyError:
        print("Bad input. `fabric_settings.py` not deleted.")
        return None

    if delete_setting:
        delete_fabric_settings()


@main.command()
def existing():
    """
    Sets up existing project local environment
    :return:
    """
    git_repo = raw_input("Enter the git repository link\n(i.e. git@github.com:mr_programmer/robot_repository.git):\t")
    project_name = get_project_name_from_repo(git_repo)
    repo_name = get_project_name_from_repo(git_repo, False)
    env.settings = {
        'git_repo': git_repo,
        'project_name': project_name
    }
    local("git clone {0}".format(git_repo))
    local("mv ./{0} ./{1}".format(repo_name, project_name))
    local("cp {0} ./".format(os.path.join(ORCHESTRATION_PROJECT_PATH, "Vagrantfile")))
    recursive_file_modify('./Vagrantfile', env.settings, is_dir=False)
    local("vagrant up")


@main.command()
def add_settings():
    """
    Adds `fabric_settings.py` to this directory
    :return: Void
    """
    public_key, private_key = generate_ssh_keypair()
    SETTINGS = {
        'git_public_key': public_key,
        'git_private_key': private_key,
        'vagrant': {
            'db_pw': generate_printable_string(15, False),
            'secret_key': generate_printable_string(40)
        }
    }
    if 'fabric_settings.py' in os.listdir('.'):
        continue_process = raw_input('You already have `fabric_settings.py in this folder. Overwrite? (Y/N)')
        if continue_process.lower() == 'y':
            pass
        else:
            print("Aborted.")
            return False
    local('cp {0} ./fabric_settings.py'.format(os.path.join(FABFILE_PATH, "fabric_settings.py.default.py")))
    recursive_file_modify('./fabric_settings.py', SETTINGS, is_dir=False)
    print("".join(("You now have `fabric_settings.py`. Edit this file to have the correct ",
                   "values and then enter `fab setup.new`")))



import os
from setuptools import setup, find_packages


def read(filepathname):
    with open(os.path.join(os.path.dirname(__file__), filepathname), 'r') as f:
        return f.read()


def get_package_data_files():
    package_data_files = []
    for orchestration, dirnames, filenames in os.walk('yurt/orchestration/'):
        for filename in filenames:
            package_data_files.append(os.path.join(orchestration.split('/', 1)[1], filename))
        for templates, dirnames, filenames in os.walk('yurt/templates/'):
            for filename in filenames:
                package_data_files.append(os.path.join(templates.split('/', 1)[1], filename))
    print package_data_files
    return package_data_files


long_description = "{}\n\n{}".format(read("README.rst"),
                                     read("CONTRIBUTORS.rst"))


setup(
    name="yak-yurt",
    packages=find_packages(),
    package_data={'yurt': get_package_data_files()},
    include_package_data=True,
    version="0.1.dev21",
    description="A tool for deploying Django Web Apps to remote servers",
    long_description=long_description,
    url="https://github.com/yeti/yurt/",
    license="MIT",
    author="Dean Mercado",
    author_email="support@yeti.co",
    install_requires=[
        "Fabric",
        "ansible",
        "pycrypto==2.5",
        "click"
    ],
    entry_points={
        "console_scripts": [
            "yurt=yurt.fabfile.cli:main",
        ]
    },
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
